# iotapay main class
from iota import Address, ProposedTransaction, Tag, Transaction, Iota, TryteString, json
import time, json

class iotapay:
    def __init__(self, provider, seed, address=None):
        self.seed = seed
        self.provider = provider
        self.api = Iota(self.provider, self.seed)

    def pay(self, data):
        try:
            json_data = data['json_data']
            json_string = json.dumps(json_data)
            trytes = TryteString.from_string(json_string)
            # Send Transfer
            sent_transfer = self.api.send_transfer(
                    depth = 3,
                    transfers = [
                            ProposedTransaction(
                                address =  Address(data['to_address']),
                                value = data['amount'],
                                tag = Tag(data['tag']),
                                message = trytes,
                            ),
                        ]
                    )
            bo = sent_transfer['bundle']
            return {
                    'status': 200,
                    'transaction_hash': bo.as_json_compatible()[0]['hash_'],
                    'message': 'Successfully Sent!'
                }
        except Exception as pe:
            # print('pe:', pe)
            return {
                    'status': 400,
                    'error': '',
                    # 'balance': str(pe.context['total_balance']),
                    'message': str(pe).split('(')[0]
                }

    def get_balance(self, data):
        try:
            if 'address' in data:
                balance_result = self.api.get_balances([data['address']])
                balance = balance_result['balances'][0]
            else:
                gna_result = self.api.get_new_addresses(index=0, count=50) # generate 50 addresses.
                addresses = gna_result['addresses']
                balance_result = self.api.get_balances(addresses)
                balance = 0
                for i in range(len(balance_result['balances'])):
                    balance = balance + balance_result['balances'][i]
            return {
                    'status': 200,
                    'balance': balance,
                    'message': 'Successfully Retrieved!'
                }
        except Exception as pe:
            # print('pe:', pe)
            return {
                    'status': 400,
                    'error': '',
                    # 'balance': str(pe.context['total_balance']),
                    # 'message': str(pe).split('(')[0]
                }

    def collect(self, data):
        print('send request to collect payment.')
        return;

    def generate_invoice(self, data):
        print('generate invoice.')
        return;



print('\x1b[H\x1b[2J') # clear console.
# Importing package
from iotapay import iotapay

# Generate a random seed
seed = 'KGWH9PTURNDTSHSQVNLOSFMSTQLHRTTQGDTFJHEKRNPVDRQGHQENANLSXXCXGICCVWBQHMHWPYZSHJYTC'

provider_url = 'https://potato.iotasalad.org:14265'

# Initialising class
iotapay = Iotapay(provider_url, seed)
# iotapay = Iotapay(seed, address)

# Calling Pay function
pay_request_data = {
        'json_data': {
            'version': '0.0.2',
        },
        'tag': 'ACYCLICIOTAPAYLIOTA99999999',
        'to_address': 'VWI9EOOFONVTODFNNWVDBOZHMUAPBKOELPMWCCMBLICGRUSXBPM9XMRVFSLXAYIYKNOJITDTWEEIGLVHXRHSDVSFLD',
        'amount': 1
    }

# paid_result = iotapay.pay(pay_request_data)
# print('paid_result:', paid_result)

# Get Balance API
# Case 1: Get balance for particular address.
# get_balance_data = { 'address': 'RSBOFMLYCMTZFPPFHFRMECWZALIEKIOIPMZJBKWILLFI9RQUAHUMFPRMQDGNMGCOHZRUPZWVLGZLPFAPWKMGLNJ9JW' }

# Case 2: Get balance for x addresses connected to the seed.
get_balance_data = {}

# balance_result = iotapay.get_balance({})
# print('balance_result:', balance_result)
